@@ -1,5 +1,5 @@
 /*
- * $ReleaseVersion: 0.1.3 $
+ * $ReleaseVersion: 0.1.6 $
  *
  * This program must be called with the constant name as the CONSTANT_NAME
  * define. If this is not the case, then a generic version which takes a
@@ -45,6 +45,12 @@
 #endif
 
 #ifdef HAVE_SYS_CONF_H
+# ifdef HAVE_SYS_PARAM_H
+# include <sys/param.h>
+# endif
+# ifdef HAVE_TIME_H
+# include <time.h>
+# endif
 #include <sys/conf.h>
 #endif
 
@@ -76,6 +82,33 @@
 #include <termios.h>
 #endif
 
+#ifdef HAVE_WINDOWS_H
+#define Win32_Winsock
+#include <windows.h>
+/* This directive is checked only for mingw32 2.8.1 */
+
+/* Absent declarations */
+#define POLLIN 1
+#define POLLPRI 2
+#define POLLOUT 4
+
+/* Undefine cygwin specific declarations to replace them */
+#undef EINTR
+#undef EWOULDBLOCK
+#undef EINPROGRESS
+#undef EALREADY
+#undef EISCONN
+#undef ECONNREFUSED
+
+/* Replace with Windows sockets declaration */
+#define EINTR		WSAEINTR
+#define EWOULDBLOCK	WSAEWOULDBLOCK
+#define EINPROGRESS	WSAEINPROGRESS
+#define EALREADY	WSAEALREADY
+#define EISCONN		WSAEISCONN
+#define ECONNREFUSED	WSAECONNREFUSED
+#endif
+
 static char *
 capitalize (char *name)
 {
